package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertRevAppl;

public interface IBisTtsaCertRevApplService {
    BisTtsaCertRevAppl selectBisTtsaCertRevApplByGuid(String guid);
    List<BisTtsaCertRevAppl> selectBisTtsaCertRevApplList(BisTtsaCertRevAppl bisTtsaCertRevAppl);
    int insertBisTtsaCertRevAppl(BisTtsaCertRevAppl bisTtsaCertRevAppl);
    int updateBisTtsaCertRevAppl(BisTtsaCertRevAppl bisTtsaCertRevAppl);
    int deleteBisTtsaCertRevApplByGuid(String guid);
    int deleteBisTtsaCertRevApplByGuids(String[] guids);
}
