package com.goldenwater.slaj.ttsa.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.goldenwater.common.annotation.Log;
import com.goldenwater.common.core.controller.BaseController;
import com.goldenwater.common.core.domain.AjaxResult;
import com.goldenwater.common.core.page.TableDataInfo;
import com.goldenwater.common.enums.BusinessType;
import com.goldenwater.common.utils.poi.ExcelUtil;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertRevAppl;
import com.goldenwater.slaj.ttsa.service.IBisTtsaCertRevApplService;

@RestController
@RequestMapping("/ttsa/ttsacertrevappl")
public class BisTtsaCertRevApplController extends BaseController {
    @Autowired
    private IBisTtsaCertRevApplService bisTtsaCertRevApplService;

    @GetMapping("/list")
    public TableDataInfo list(BisTtsaCertRevAppl bisTtsaCertRevAppl) {
        startPage();
        List<BisTtsaCertRevAppl> list = bisTtsaCertRevApplService.selectBisTtsaCertRevApplList(bisTtsaCertRevAppl);
        return getDataTable(list);
    }

    @GetMapping("/{guid}")
    public AjaxResult getInfo(@PathVariable String guid) {
        return AjaxResult.success(bisTtsaCertRevApplService.selectBisTtsaCertRevApplByGuid(guid));
    }

    @PostMapping
    public AjaxResult add(@RequestBody BisTtsaCertRevAppl bisTtsaCertRevAppl) {
        return toAjax(bisTtsaCertRevApplService.insertBisTtsaCertRevAppl(bisTtsaCertRevAppl));
    }

    @PutMapping
    public AjaxResult edit(@RequestBody BisTtsaCertRevAppl bisTtsaCertRevAppl) {
        return toAjax(bisTtsaCertRevApplService.updateBisTtsaCertRevAppl(bisTtsaCertRevAppl));
    }

    @DeleteMapping("/{guids}")
    public AjaxResult remove(@PathVariable String[] guids) {
        return toAjax(bisTtsaCertRevApplService.deleteBisTtsaCertRevApplByGuids(guids));
    }

    @Log(title = "撤销申请管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('ttsa:ttsacertrevappl:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BisTtsaCertRevAppl bisTtsaCertRevAppl) {
        List<BisTtsaCertRevAppl> list = bisTtsaCertRevApplService.selectBisTtsaCertRevApplList(bisTtsaCertRevAppl);
        ExcelUtil<BisTtsaCertRevAppl> util = new ExcelUtil<BisTtsaCertRevAppl>(BisTtsaCertRevAppl.class);
        util.exportExcel(response, list, "撤销申请管理数据");
    }
}
